==> openshift-model-installer-6.9.0-sources.jar: io/fabric8/openshift/api/model/installer/baremetal/v1/BMCFluent.java <==
package io.fabric8.openshift.api.model.installer.baremetal.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class BMCFluent<A extends BMCFluent<A>> extends BaseFluent<A>{
  public BMCFluent() {
  }
  
  public BMCFluent(BMC instance) {
    this.copyInstance(instance);
  }
  private String address;
  private Boolean disableCertificateVerification;
  private String password;
  private String username;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(BMC instance) {
    instance = (instance != null ? instance : new BMC());
  
    if (instance != null) {
        this.withAddress(instance.getAddress());
        this.withDisableCertificateVerification(instance.getDisableCertificateVerification());
        this.withPassword(instance.getPassword());
        this.withUsername(instance.getUsername());
        this.withAddress(instance.getAddress());
        this.withDisableCertificateVerification(instance.getDisableCertificateVerification());
        this.withPassword(instance.getPassword());
        this.withUsername(instance.getUsername());
        this.withAdditionalProperties(instance.getAdditionalProperties());
      }
  }
  
  public String getAddress() {
    return this.address;
  }
  
  public A withAddress(String address) {
    this.address=address; return (A) this;
  }
  
  public boolean hasAddress() {
    return this.address != null;
  }
  
  public Boolean getDisableCertificateVerification() {
    return this.disableCertificateVerification;
  }
  
  public A withDisableCertificateVerification(Boolean disableCertificateVerification) {
    this.disableCertificateVerification=disableCertificateVerification; return (A) this;
  }
  
  public boolean hasDisableCertificateVerification() {
    return this.disableCertificateVerification != null;
  }
  
  public String getPassword() {
    return this.password;
  }
  
  public A withPassword(String password) {
    this.password=password; return (A) this;
  }
  
  public boolean hasPassword() {
    return this.password != null;
  }
  
  public String getUsername() {
    return this.username;
  }
  
  public A withUsername(String username) {
    this.username=username; return (A) this;
  }
  
  public boolean hasUsername() {
    return this.username != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    BMCFluent that = (BMCFluent) o;
    if (!java.util.Objects.equals(address, that.address)) return false;
  
    if (!java.util.Objects.equals(disableCertificateVerification, that.disableCertificateVerification)) return false;
  
    if (!java.util.Objects.equals(password, that.password)) return false;
  
    if (!java.util.Objects.equals(username, that.username)) return false;
  
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(address,  disableCertificateVerification,  password,  username,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (address != null) { sb.append("address:"); sb.append(address + ","); }
    if (disableCertificateVerification != null) { sb.append("disableCertificateVerification:"); sb.append(disableCertificateVerification + ","); }
    if (password != null) { sb.append("password:"); sb.append(password + ","); }
    if (username != null) { sb.append("username:"); sb.append(username + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
  public A withDisableCertificateVerification() {
    return withDisableCertificateVerification(true);
  }
  

}

==> openshift-model-installer-6.9.1-sources.jar: io/fabric8/openshift/api/model/installer/baremetal/v1/BMCFluent.java <==
package io.fabric8.openshift.api.model.installer.baremetal.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class BMCFluent<A extends BMCFluent<A>> extends BaseFluent<A>{
  public BMCFluent() {
  }
  
  public BMCFluent(BMC instance) {
    this.copyInstance(instance);
  }
  private String address;
  private Boolean disableCertificateVerification;
  private String password;
  private String username;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(BMC instance) {
    instance = (instance != null ? instance : new BMC());
    if (instance != null) {
          this.withAddress(instance.getAddress());
          this.withDisableCertificateVerification(instance.getDisableCertificateVerification());
          this.withPassword(instance.getPassword());
          this.withUsername(instance.getUsername());
          this.withAddress(instance.getAddress());
          this.withDisableCertificateVerification(instance.getDisableCertificateVerification());
          this.withPassword(instance.getPassword());
          this.withUsername(instance.getUsername());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public String getAddress() {
    return this.address;
  }
  
  public A withAddress(String address) {
    this.address = address;
    return (A) this;
  }
  
  public boolean hasAddress() {
    return this.address != null;
  }
  
  public Boolean getDisableCertificateVerification() {
    return this.disableCertificateVerification;
  }
  
  public A withDisableCertificateVerification(Boolean disableCertificateVerification) {
    this.disableCertificateVerification = disableCertificateVerification;
    return (A) this;
  }
  
  public boolean hasDisableCertificateVerification() {
    return this.disableCertificateVerification != null;
  }
  
  public String getPassword() {
    return this.password;
  }
  
  public A withPassword(String password) {
    this.password = password;
    return (A) this;
  }
  
  public boolean hasPassword() {
    return this.password != null;
  }
  
  public String getUsername() {
    return this.username;
  }
  
  public A withUsername(String username) {
    this.username = username;
    return (A) this;
  }
  
  public boolean hasUsername() {
    return this.username != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    BMCFluent that = (BMCFluent) o;
    if (!java.util.Objects.equals(address, that.address)) return false;
    if (!java.util.Objects.equals(disableCertificateVerification, that.disableCertificateVerification)) return false;
    if (!java.util.Objects.equals(password, that.password)) return false;
    if (!java.util.Objects.equals(username, that.username)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(address,  disableCertificateVerification,  password,  username,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (address != null) { sb.append("address:"); sb.append(address + ","); }
    if (disableCertificateVerification != null) { sb.append("disableCertificateVerification:"); sb.append(disableCertificateVerification + ","); }
    if (password != null) { sb.append("password:"); sb.append(password + ","); }
    if (username != null) { sb.append("username:"); sb.append(username + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
  public A withDisableCertificateVerification() {
    return withDisableCertificateVerification(true);
  }
  

}
